@@ -1,6 +1,6 @@
 // Copyright (C)2004 Landmark Graphics Corporation
 // Copyright (C)2005, 2006 Sun Microsystems, Inc.
-// Copyright (C)2009, 2011, 2013-2016, 2018-2019 D. R. Commander
+// Copyright (C)2009, 2011, 2013-2016, 2018-2020 D. R. Commander
 //
 // This library is free software and may be redistributed and/or modified under
 // the terms of the wxWindows Library License, Version 3.1 or (at your option)
@@ -334,115 +334,115 @@ extern "C" {
 // GLX 1.0 functions
 
 FUNCDEF3(XVisualInfo *, glXChooseVisual, Display *, dpy, int, screen,
-	int *, attrib_list, glXChooseVisual);
+	int *, attrib_list, glXChooseVisual)
 
 VFUNCDEF4(glXCopyContext, Display *, dpy, GLXContext, src, GLXContext, dst,
-	unsigned long, mask, glXCopyContext);
+	unsigned long, mask, glXCopyContext)
 
 FUNCDEF4(GLXContext, glXCreateContext, Display *, dpy, XVisualInfo *, vis,
-	GLXContext, share_list, Bool, direct, glXCreateContext);
+	GLXContext, share_list, Bool, direct, glXCreateContext)
 
 FUNCDEF3(GLXPixmap, glXCreateGLXPixmap, Display *, dpy, XVisualInfo *, vis,
-	Pixmap, pixmap, glXCreateGLXPixmap);
+	Pixmap, pixmap, glXCreateGLXPixmap)
 
 VFUNCDEF2(glXDestroyContext, Display *, dpy, GLXContext, ctx,
-	glXDestroyContext);
+	glXDestroyContext)
 
 VFUNCDEF2(glXDestroyGLXPixmap, Display *, dpy, GLXPixmap, pix,
-	glXDestroyGLXPixmap);
+	glXDestroyGLXPixmap)
 
 FUNCDEF4(int, glXGetConfig, Display *, dpy, XVisualInfo *, vis, int, attrib,
-	int *, value, glXGetConfig);
+	int *, value, glXGetConfig)
 
-FUNCDEF0(GLXDrawable, glXGetCurrentDrawable, glXGetCurrentDrawable);
+FUNCDEF0(GLXDrawable, glXGetCurrentDrawable, glXGetCurrentDrawable)
 
-FUNCDEF2(Bool, glXIsDirect, Display *, dpy, GLXContext, ctx, glXIsDirect);
+FUNCDEF2(Bool, glXIsDirect, Display *, dpy, GLXContext, ctx, glXIsDirect)
 
 FUNCDEF3(Bool, glXMakeCurrent, Display *, dpy, GLXDrawable, drawable,
-	GLXContext, ctx, glXMakeCurrent);
+	GLXContext, ctx, glXMakeCurrent)
 
 FUNCDEF3(Bool, glXQueryExtension, Display *, dpy, int *, error_base,
-	int *, event_base, glXQueryExtension);
+	int *, event_base, glXQueryExtension)
 
 FUNCDEF3(Bool, glXQueryVersion, Display *, dpy, int *, major, int *, minor,
-	glXQueryVersion);
+	glXQueryVersion)
 
 VFUNCDEF2(glXSwapBuffers, Display *, dpy, GLXDrawable, drawable,
-	glXSwapBuffers);
+	glXSwapBuffers)
 
 VFUNCDEF4(glXUseXFont, Font, font, int, first, int, count, int, list_base,
-	glXUseXFont);
+	glXUseXFont)
 
-VFUNCDEF0(glXWaitGL, glXWaitGL);
+VFUNCDEF0(glXWaitGL, glXWaitGL)
 
 
 // GLX 1.1 functions
 
 FUNCDEF2(const char *, glXGetClientString, Display *, dpy, int, name,
-	glXGetClientString);
+	glXGetClientString)
 
 FUNCDEF3(const char *, glXQueryServerString, Display *, dpy, int, screen, int,
-	name, glXQueryServerString);
+	name, glXQueryServerString)
 
 FUNCDEF2(const char *, glXQueryExtensionsString, Display *, dpy, int, screen,
-	glXQueryExtensionsString);
+	glXQueryExtensionsString)
 
 
 // GLX 1.2 functions
 
-FUNCDEF0(Display *, glXGetCurrentDisplay, glXGetCurrentDisplay);
+FUNCDEF0(Display *, glXGetCurrentDisplay, glXGetCurrentDisplay)
 
 
 // GLX 1.3 functions
 
 FUNCDEF4(GLXFBConfig *, glXChooseFBConfig, Display *, dpy, int, screen,
-	const int *, attrib_list, int *, nelements, glXChooseFBConfig);
+	const int *, attrib_list, int *, nelements, glXChooseFBConfig)
 
 FUNCDEF5(GLXContext, glXCreateNewContext, Display *, dpy, GLXFBConfig, config,
-	int, render_type, GLXContext, share_list, Bool, direct, glXCreateNewContext);
+	int, render_type, GLXContext, share_list, Bool, direct, glXCreateNewContext)
 
 FUNCDEF3(GLXPbuffer, glXCreatePbuffer, Display *, dpy, GLXFBConfig, config,
-	const int *, attrib_list, glXCreatePbuffer);
+	const int *, attrib_list, glXCreatePbuffer)
 
 FUNCDEF4(GLXPixmap, glXCreatePixmap, Display *, dpy, GLXFBConfig, config,
-	Pixmap, pixmap, const int *, attrib_list, glXCreatePixmap);
+	Pixmap, pixmap, const int *, attrib_list, glXCreatePixmap)
 
 FUNCDEF4(GLXWindow, glXCreateWindow, Display *, dpy, GLXFBConfig, config,
-	Window, win, const int *, attrib_list, glXCreateWindow);
+	Window, win, const int *, attrib_list, glXCreateWindow)
 
 VFUNCDEF2(glXDestroyPbuffer, Display *, dpy, GLXPbuffer, pbuf,
-	glXDestroyPbuffer);
+	glXDestroyPbuffer)
 
 VFUNCDEF2(glXDestroyPixmap, Display *, dpy, GLXPixmap, pixmap,
-	glXDestroyPixmap);
+	glXDestroyPixmap)
 
-VFUNCDEF2(glXDestroyWindow, Display *, dpy, GLXWindow, win, glXDestroyWindow);
+VFUNCDEF2(glXDestroyWindow, Display *, dpy, GLXWindow, win, glXDestroyWindow)
 
-FUNCDEF0(GLXDrawable, glXGetCurrentReadDrawable, glXGetCurrentReadDrawable);
+FUNCDEF0(GLXDrawable, glXGetCurrentReadDrawable, glXGetCurrentReadDrawable)
 
 FUNCDEF4(int, glXGetFBConfigAttrib, Display *, dpy, GLXFBConfig, config,
-	int, attribute, int *, value, glXGetFBConfigAttrib);
+	int, attribute, int *, value, glXGetFBConfigAttrib)
 
 FUNCDEF3(GLXFBConfig *, glXGetFBConfigs, Display *, dpy, int, screen,
-	int *, nelements, glXGetFBConfigs);
+	int *, nelements, glXGetFBConfigs)
 
 VFUNCDEF3(glXGetSelectedEvent, Display *, dpy, GLXDrawable, draw,
-	unsigned long *, event_mask, glXGetSelectedEvent);
+	unsigned long *, event_mask, glXGetSelectedEvent)
 
 FUNCDEF2(XVisualInfo *, glXGetVisualFromFBConfig, Display *, dpy,
-	GLXFBConfig, config, glXGetVisualFromFBConfig);
+	GLXFBConfig, config, glXGetVisualFromFBConfig)
 
 FUNCDEF4(Bool, glXMakeContextCurrent, Display *, display, GLXDrawable, draw,
-	GLXDrawable, read, GLXContext, ctx, glXMakeContextCurrent);
+	GLXDrawable, read, GLXContext, ctx, glXMakeContextCurrent)
 
 FUNCDEF4(int, glXQueryContext, Display *, dpy, GLXContext, ctx, int, attribute,
-	int *, value, glXQueryContext);
+	int *, value, glXQueryContext)
 
 VFUNCDEF4(glXQueryDrawable, Display *, dpy, GLXDrawable, draw, int, attribute,
-	unsigned int *, value, glXQueryDrawable);
+	unsigned int *, value, glXQueryDrawable)
 
 VFUNCDEF3(glXSelectEvent, Display *, dpy, GLXDrawable, draw,
-	unsigned long, event_mask, glXSelectEvent);
+	unsigned long, event_mask, glXSelectEvent)
 
 
 // GLX 1.4 functions
@@ -460,7 +460,7 @@ static INLINE void (*_glXGetProcAddress(const GLubyte *procName))(void)
 
 FUNCDEF5(GLXContext, glXCreateContextAttribsARB, Display *, dpy, GLXFBConfig,
 	config, GLXContext, share_context, Bool, direct, const int *, attribs,
-	glXCreateContextAttribsARB);
+	glXCreateContextAttribsARB)
 
 
 // GLX_ARB_get_proc_address
@@ -477,25 +477,25 @@ static INLINE void (*_glXGetProcAddressARB(const GLubyte *procName))(void)
 // GLX_EXT_import_context
 
 VFUNCDEF2(glXFreeContextEXT, Display *, dpy, GLXContext, ctx,
-	glXFreeContextEXT);
+	glXFreeContextEXT)
 
 FUNCDEF2(GLXContext, glXImportContextEXT, Display *, dpy,
-	GLXContextID, contextID, glXImportContextEXT);
+	GLXContextID, contextID, glXImportContextEXT)
 
 FUNCDEF4(int, glXQueryContextInfoEXT, Display *, dpy, GLXContext, ctx,
-	int, attribute, int *, value, glXQueryContextInfoEXT);
+	int, attribute, int *, value, glXQueryContextInfoEXT)
 
 
 // GLX_EXT_swap_control
 
 VFUNCDEF3(glXSwapIntervalEXT, Display *, dpy, GLXDrawable, drawable, int,
-	interval, glXSwapIntervalEXT);
+	interval, glXSwapIntervalEXT)
 
 
 // GLX_EXT_texture_from_pixmap
 
 VFUNCDEF4(glXBindTexImageEXT, Display *, dpy, GLXDrawable, drawable,
-	int, buffer, const int *, attrib_list, glXBindTexImageEXT);
+	int, buffer, const int *, attrib_list, glXBindTexImageEXT)
 
 VFUNCDEF3(glXReleaseTexImageEXT, Display *, dpy, GLXDrawable, drawable,
 	int, buffer, glXReleaseTexImageEXT)
@@ -504,58 +504,66 @@ VFUNCDEF3(glXReleaseTexImageEXT, Display *, dpy, GLXDrawable, drawable,
 // GLX_NV_swap_group
 
 FUNCDEF3(Bool, glXJoinSwapGroupNV, Display *, dpy, GLXDrawable, drawable,
-	GLuint, group, glXJoinSwapGroupNV);
+	GLuint, group, glXJoinSwapGroupNV)
 
 FUNCDEF3(Bool, glXBindSwapBarrierNV, Display *, dpy, GLuint, group,
-	GLuint, barrier, glXBindSwapBarrierNV);
+	GLuint, barrier, glXBindSwapBarrierNV)
 
 FUNCDEF4(Bool, glXQuerySwapGroupNV, Display *, dpy, GLXDrawable, drawable,
-	GLuint *, group, GLuint *, barrier, glXQuerySwapGroupNV);
+	GLuint *, group, GLuint *, barrier, glXQuerySwapGroupNV)
 
 FUNCDEF4(Bool, glXQueryMaxSwapGroupsNV, Display *, dpy, int, screen,
-	GLuint *, maxGroups, GLuint *, maxBarriers, glXQueryMaxSwapGroupsNV);
+	GLuint *, maxGroups, GLuint *, maxBarriers, glXQueryMaxSwapGroupsNV)
 
 FUNCDEF3(Bool, glXQueryFrameCountNV, Display *, dpy, int, screen,
-	GLuint *, count, glXQueryFrameCountNV);
+	GLuint *, count, glXQueryFrameCountNV)
 
 FUNCDEF2(Bool, glXResetFrameCountNV, Display *, dpy, int, screen,
-	glXResetFrameCountNV);
+	glXResetFrameCountNV)
 
 
 // GLX_SGI_swap_control
 
-FUNCDEF1(int, glXSwapIntervalSGI, int, interval, glXSwapIntervalSGI);
+FUNCDEF1(int, glXSwapIntervalSGI, int, interval, glXSwapIntervalSGI)
 
 
 // GLX_SGIX_fbconfig
 
 FUNCDEF2(GLXFBConfigSGIX, glXGetFBConfigFromVisualSGIX, Display *, dpy,
-	XVisualInfo *, vis, glXGetFBConfigFromVisualSGIX);
+	XVisualInfo *, vis, glXGetFBConfigFromVisualSGIX)
 
 
 // GLX_SUN_get_transparent_index
 
+#if defined(GLX_GLXEXT_VERSION) && GLX_GLXEXT_VERSION >= 20190000
 FUNCDEF4(int, glXGetTransparentIndexSUN, Display *, dpy, Window, overlay,
-	Window, underlay, long *, transparentIndex, glXGetTransparentIndexSUN);
+	Window, underlay, unsigned long *, transparentIndex,
+	glXGetTransparentIndexSUN)
+#else
+FUNCDEF4(int, glXGetTransparentIndexSUN, Display *, dpy, Window, overlay,
+	Window, underlay, long *, transparentIndex, glXGetTransparentIndexSUN)
+#endif
 
 
 // GL functions
 
-VFUNCDEF0(glFinish, glFinish);
+VFUNCDEF0(glFinish, glFinish)
 
-VFUNCDEF0(glFlush, glFlush);
+VFUNCDEF0(glFlush, glFlush)
 
-FUNCDEF1(const GLubyte *, glGetString, GLenum, name, glGetString);
+VFUNCDEF1(glDrawBuffer, GLenum, drawbuf, glDrawBuffer)
+
+VFUNCDEF2(glDrawBuffers, GLsizei, n, const GLenum *, bufs, glDrawBuffers)
+
+FUNCDEF1(const GLubyte *, glGetString, GLenum, name, glGetString)
 
 FUNCDEF2(const GLubyte *, glGetStringi, GLenum, name, GLuint, index,
-	glGetStringi);
+	glGetStringi)
+
+VFUNCDEF0(glPopAttrib, glPopAttrib)
 
 VFUNCDEF4(glViewport, GLint, x, GLint, y, GLsizei, width, GLsizei, height,
-	glViewport);
-
-VFUNCDEF1(glDrawBuffer, GLenum, drawbuf, glDrawBuffer);
-
-VFUNCDEF0(glPopAttrib, glPopAttrib);
+	glViewport)
 
 
 #ifdef FAKEOPENCL
@@ -566,7 +574,7 @@ typedef void (*pfn_notifyType)(const char *, const void *, size_t, void *);
 FUNCDEF6(cl_context, clCreateContext,
 	const cl_context_properties *, properties, cl_uint, num_devices,
 	const cl_device_id *, devices, pfn_notifyType, pfn_notify, void *, user_data,
-	cl_int *, errcode_ret, clCreateContext);
+	cl_int *, errcode_ret, clCreateContext)
 
 #endif
 
@@ -574,76 +582,76 @@ FUNCDEF6(cl_context, clCreateContext,
 // X11 functions
 
 FUNCDEF3(Bool, XCheckMaskEvent, Display *, dpy, long, event_mask, XEvent *, xe,
-	XCheckMaskEvent);
+	XCheckMaskEvent)
 
 FUNCDEF3(Bool, XCheckTypedEvent, Display *, dpy, int, event_type, XEvent *, xe,
-	XCheckTypedEvent);
+	XCheckTypedEvent)
 
 FUNCDEF4(Bool, XCheckTypedWindowEvent, Display *, dpy, Window, win,
-	int, event_type, XEvent *, xe, XCheckTypedWindowEvent);
+	int, event_type, XEvent *, xe, XCheckTypedWindowEvent)
 
 FUNCDEF4(Bool, XCheckWindowEvent, Display *, dpy, Window, win, long,
-	event_mask, XEvent *, xe, XCheckWindowEvent);
+	event_mask, XEvent *, xe, XCheckWindowEvent)
 
-FUNCDEF1(int, XCloseDisplay, Display *, dpy, XCloseDisplay);
+FUNCDEF1(int, XCloseDisplay, Display *, dpy, XCloseDisplay)
 
 FUNCDEF4(int, XConfigureWindow, Display *, dpy, Window, win,
-	unsigned int, value_mask, XWindowChanges *, values, XConfigureWindow);
+	unsigned int, value_mask, XWindowChanges *, values, XConfigureWindow)
 
 FUNCDEF10(int, XCopyArea, Display *, dpy, Drawable, src, Drawable, dst, GC, gc,
 	int, src_x, int, src_y, unsigned int, w, unsigned int, h, int, dest_x,
-	int, dest_y, XCopyArea);
+	int, dest_y, XCopyArea)
 
 FUNCDEF9(Window, XCreateSimpleWindow, Display *, dpy, Window, parent, int, x,
 	int, y, unsigned int, width, unsigned int, height, unsigned int,
 	border_width, unsigned long, border, unsigned long, background,
-	XCreateSimpleWindow);
+	XCreateSimpleWindow)
 
 FUNCDEF12(Window, XCreateWindow, Display *, dpy, Window, parent, int, x,
 	int, y, unsigned int, width, unsigned int, height,
 	unsigned int, border_width, int, depth, unsigned int, c_class,
 	Visual *, visual, unsigned long, value_mask,
-	XSetWindowAttributes *, attributes, XCreateWindow);
+	XSetWindowAttributes *, attributes, XCreateWindow)
 
 FUNCDEF2(int, XDestroySubwindows, Display *, dpy, Window, win,
-	XDestroySubwindows);
+	XDestroySubwindows)
 
-FUNCDEF2(int, XDestroyWindow, Display *, dpy, Window, win, XDestroyWindow);
+FUNCDEF2(int, XDestroyWindow, Display *, dpy, Window, win, XDestroyWindow)
 
-FUNCDEF1(int, XFree, void *, data, XFree);
+FUNCDEF1(int, XFree, void *, data, XFree)
 
 FUNCDEF9(Status, XGetGeometry, Display *, display, Drawable, d, Window *, root,
 	int *, x, int *, y, unsigned int *, width, unsigned int *, height,
-	unsigned int *, border_width, unsigned int *, depth, XGetGeometry);
+	unsigned int *, border_width, unsigned int *, depth, XGetGeometry)
 
 FUNCDEF8(XImage *, XGetImage, Display *, display, Drawable, d, int, x, int, y,
 	unsigned int, width, unsigned int, height, unsigned long, plane_mask,
-	int, format, XGetImage);
+	int, format, XGetImage)
 
 FUNCDEF2(char **, XListExtensions, Display *, dpy, int *, next,
-	XListExtensions);
+	XListExtensions)
 
 FUNCDEF3(int, XMaskEvent, Display *, dpy, long, event_mask, XEvent *, xe,
-	XMaskEvent);
+	XMaskEvent)
 
 FUNCDEF6(int, XMoveResizeWindow, Display *, dpy, Window, win, int, x, int, y,
-	unsigned int, width, unsigned int, height, XMoveResizeWindow);
+	unsigned int, width, unsigned int, height, XMoveResizeWindow)
 
-FUNCDEF2(int, XNextEvent, Display *, dpy, XEvent *, xe, XNextEvent);
+FUNCDEF2(int, XNextEvent, Display *, dpy, XEvent *, xe, XNextEvent)
 
-FUNCDEF1(Display *, XOpenDisplay, _Xconst char *, name, XOpenDisplay);
+FUNCDEF1(Display *, XOpenDisplay, _Xconst char *, name, XOpenDisplay)
 
 FUNCDEF5(Bool, XQueryExtension, Display *, dpy, _Xconst char *, name,
 	int *, major_opcode, int *, first_event, int *, first_error,
-	XQueryExtension);
+	XQueryExtension)
 
 FUNCDEF4(int, XResizeWindow, Display *, dpy, Window, win, unsigned int, width,
-	unsigned int, height, XResizeWindow);
+	unsigned int, height, XResizeWindow)
 
-FUNCDEF1(char *, XServerVendor, Display *, dpy, XServerVendor);
+FUNCDEF1(char *, XServerVendor, Display *, dpy, XServerVendor)
 
 FUNCDEF4(int, XWindowEvent, Display *, dpy, Window, win, long, event_mask,
-	XEvent *, xe, XWindowEvent);
+	XEvent *, xe, XWindowEvent)
 
 
 // From dlfaker
@@ -658,24 +666,24 @@ SYMDEF(dlopen);
 // XCB functions
 
 FUNCDEF2(const xcb_query_extension_reply_t *, xcb_get_extension_data,
-	xcb_connection_t *, conn, xcb_extension_t *, ext, xcb_get_extension_data);
+	xcb_connection_t *, conn, xcb_extension_t *, ext, xcb_get_extension_data)
 
 FUNCDEF3(xcb_glx_query_version_cookie_t, xcb_glx_query_version,
 	xcb_connection_t *, conn, uint32_t, major_version, uint32_t, minor_version,
-	xcb_glx_query_version);
+	xcb_glx_query_version)
 
 FUNCDEF3(xcb_glx_query_version_reply_t *, xcb_glx_query_version_reply,
 	xcb_connection_t *, conn, xcb_glx_query_version_cookie_t, cookie,
-	xcb_generic_error_t **, error, xcb_glx_query_version_reply);
+	xcb_generic_error_t **, error, xcb_glx_query_version_reply)
 
 FUNCDEF1(xcb_generic_event_t *, xcb_poll_for_event, xcb_connection_t *, conn,
-	xcb_poll_for_event);
+	xcb_poll_for_event)
 
 FUNCDEF1(xcb_generic_event_t *, xcb_poll_for_queued_event, xcb_connection_t *,
-	conn, xcb_poll_for_queued_event);
+	conn, xcb_poll_for_queued_event)
 
 FUNCDEF1(xcb_generic_event_t *, xcb_wait_for_event, xcb_connection_t *, conn,
-	xcb_wait_for_event);
+	xcb_wait_for_event)
 
 #endif
 
@@ -685,73 +693,73 @@ FUNCDEF1(xcb_generic_event_t *, xcb_wait_for_event, xcb_connection_t *, conn,
 // well as to ensure that, with 'vglrun -nodl', libGL is not loaded into the
 // process until the 3D application actually uses it.
 
-VFUNCDEF2(glBindBuffer, GLenum, target, GLuint, buffer, NULL);
+VFUNCDEF2(glBindBuffer, GLenum, target, GLuint, buffer, NULL)
 
 VFUNCDEF7(glBitmap, GLsizei, width, GLsizei, height, GLfloat, xorig,
 	GLfloat, yorig, GLfloat, xmove, GLfloat, ymove, const GLubyte *, bitmap,
-	NULL);
+	NULL)
 
 VFUNCDEF4(glBufferData, GLenum, target, GLsizeiptr, size, const GLvoid *, data,
-	GLenum, usage, NULL);
+	GLenum, usage, NULL)
 
-VFUNCDEF1(glClear, GLbitfield, mask, NULL);
+VFUNCDEF1(glClear, GLbitfield, mask, NULL)
 
 VFUNCDEF4(glClearColor, GLclampf, red, GLclampf, green, GLclampf, blue,
-	GLclampf, alpha, NULL);
+	GLclampf, alpha, NULL)
 
 VFUNCDEF5(glCopyPixels, GLint, x, GLint, y, GLsizei, width, GLsizei, height,
-	GLenum, type, NULL);
+	GLenum, type, NULL)
 
-VFUNCDEF0(glEndList, NULL);
+VFUNCDEF0(glEndList, NULL)
 
-VFUNCDEF2(glGenBuffers, GLsizei, n, GLuint *, buffers, NULL);
+VFUNCDEF2(glGenBuffers, GLsizei, n, GLuint *, buffers, NULL)
 
 VFUNCDEF3(glGetBufferParameteriv, GLenum, target, GLenum, value, GLint *, data,
-	NULL);
+	NULL)
 
-FUNCDEF0(GLenum, glGetError, NULL);
+FUNCDEF0(GLenum, glGetError, NULL)
 
-VFUNCDEF2(glGetFloatv, GLenum, pname, GLfloat *, params, NULL);
+VFUNCDEF2(glGetFloatv, GLenum, pname, GLfloat *, params, NULL)
 
-VFUNCDEF2(glGetIntegerv, GLenum, pname, GLint *, params, NULL);
+VFUNCDEF2(glGetIntegerv, GLenum, pname, GLint *, params, NULL)
 
-VFUNCDEF0(glLoadIdentity, NULL);
+VFUNCDEF0(glLoadIdentity, NULL)
 
-FUNCDEF2(void *, glMapBuffer, GLenum, target, GLenum, access, NULL);
+FUNCDEF2(void *, glMapBuffer, GLenum, target, GLenum, access, NULL)
 
-VFUNCDEF1(glMatrixMode, GLenum, mode, NULL);
+VFUNCDEF1(glMatrixMode, GLenum, mode, NULL)
 
-VFUNCDEF2(glNewList, GLuint, list, GLenum, mode, NULL);
+VFUNCDEF2(glNewList, GLuint, list, GLenum, mode, NULL)
 
 VFUNCDEF6(glOrtho, GLdouble, left, GLdouble, right, GLdouble, bottom,
-	GLdouble, top, GLdouble, near_val, GLdouble, far_val, NULL);
+	GLdouble, top, GLdouble, near_val, GLdouble, far_val, NULL)
 
-VFUNCDEF2(glPixelStorei, GLenum, pname, GLint, param, NULL);
+VFUNCDEF2(glPixelStorei, GLenum, pname, GLint, param, NULL)
 
-VFUNCDEF0(glPopMatrix, NULL);
+VFUNCDEF0(glPopMatrix, NULL)
 
-VFUNCDEF0(glPushMatrix, NULL);
+VFUNCDEF0(glPushMatrix, NULL)
 
-VFUNCDEF2(glRasterPos2i, GLint, x, GLint, y, NULL);
+VFUNCDEF2(glRasterPos2i, GLint, x, GLint, y, NULL)
 
-VFUNCDEF1(glReadBuffer, GLenum, mode, NULL);
+VFUNCDEF1(glReadBuffer, GLenum, mode, NULL)
 
 VFUNCDEF7(glReadPixels, GLint, x, GLint, y, GLsizei, width, GLsizei, height,
-	GLenum, format, GLenum, type, GLvoid *, pixels, NULL);
+	GLenum, format, GLenum, type, GLvoid *, pixels, NULL)
 
-FUNCDEF1(GLboolean, glUnmapBuffer, GLenum, target, NULL);
+FUNCDEF1(GLboolean, glUnmapBuffer, GLenum, target, NULL)
 
-FUNCDEF0(GLXContext, glXGetCurrentContext, NULL);
+FUNCDEF0(GLXContext, glXGetCurrentContext, NULL)
 
 // We load all XCB functions dynamically, so that the same VirtualGL binary
 // can be used to support systems with and without XCB libraries.
 
 #ifdef FAKEXCB
 
-FUNCDEF1(xcb_connection_t *, XGetXCBConnection, Display *, dpy, NULL);
+FUNCDEF1(xcb_connection_t *, XGetXCBConnection, Display *, dpy, NULL)
 
 VFUNCDEF2(XSetEventQueueOwner, Display *, dpy, enum XEventQueueOwner, owner,
-	XSetEventQueueOwner);
+	XSetEventQueueOwner)
 
 typedef xcb_extension_t *_xcb_glx_idType;
 SYMDEF(xcb_glx_id);
@@ -762,18 +770,18 @@ static INLINE xcb_extension_t *_xcb_glx_id(void)
 }
 
 FUNCDEF4(xcb_intern_atom_cookie_t, xcb_intern_atom, xcb_connection_t *, conn,
-	uint8_t, only_if_exists, uint16_t, name_len, const char *, name, NULL);
+	uint8_t, only_if_exists, uint16_t, name_len, const char *, name, NULL)
 
 FUNCDEF3(xcb_intern_atom_reply_t *, xcb_intern_atom_reply, xcb_connection_t *,
-	conn, xcb_intern_atom_cookie_t, cookie, xcb_generic_error_t **, e, NULL);
+	conn, xcb_intern_atom_cookie_t, cookie, xcb_generic_error_t **, e, NULL)
 
 FUNCDEF1(xcb_key_symbols_t *, xcb_key_symbols_alloc, xcb_connection_t *, c,
-	NULL);
+	NULL)
 
-VFUNCDEF1(xcb_key_symbols_free, xcb_key_symbols_t *, syms, NULL);
+VFUNCDEF1(xcb_key_symbols_free, xcb_key_symbols_t *, syms, NULL)
 
 FUNCDEF3(xcb_keysym_t, xcb_key_symbols_get_keysym, xcb_key_symbols_t *, syms,
-	xcb_keycode_t, keycode, int, col, NULL);
+	xcb_keycode_t, keycode, int, col, NULL)
 
 #endif
 
