@@ -63,7 +63,8 @@ GLXPbuffer pbuffer = 0;
 Timer timer;
 bool useWindow = false, usePixmap = false, useFBO = false, useRTT = false,
 	useAlpha = false, usePBO = false;
-int visualID = 0, loops = 1;
+unsigned int visualID;
+int loops = 1;
 #ifdef USEIFR
 bool useIFR = false;
 NvIFRAPI ifr;
@@ -344,7 +345,7 @@ void clearFB(void)
 			fprintf(stderr, "Buffer was not cleared\n");  break;
 		}
 	}
-	if(buf) free(buf);
+	free(buf);
 }
 
 
@@ -391,7 +392,7 @@ int writeTest(int format)
 		fprintf(stderr, "%s\n", e.getMessage());  retval = -1;
 	}
 
-	if(rgbaBuffer) free(rgbaBuffer);
+	free(rgbaBuffer);
 	return retval;
 }
 
@@ -554,7 +555,7 @@ int readTest(int format)
 		fprintf(stderr, "%s\n", e.getMessage());  retval = -1;
 	}
 
-	if(rgbaBuffer) free(rgbaBuffer);
+	free(rgbaBuffer);
 	if(usePBO && bufferID > 0)
 	{
 		glBindBuffer(GL_PIXEL_PACK_BUFFER_EXT, 0);
